@@ -3,7 +3,6 @@ package fuku.xml2eb.converter.wdic;
 import java.awt.image.BufferedImage;
 import java.io.File;
 import java.io.IOException;
-import java.util.Arrays;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Iterator;
@@ -62,7 +61,7 @@ public class Wdic2Xml {
         "0x" + HexUtil.toHexString(CatalogInfo.TYPE_GENERAL, 2);
 
     /** ログ */
-    private transient Log _log = null;
+    private Log _log = null;
     /** ベースディレクトリ */
     private File _basedir = null;
     /** WDICグループリスト */
@@ -1664,17 +1663,17 @@ public class Wdic2Xml {
             }
 
             if (ch == '\'') {
-                String bracket = "'";
+                StringBuilder bracket = new StringBuilder("'");
                 int idx1 = i + 1;
                 for (; idx1<len; idx1++) {
                     if (str.charAt(idx1) != '\'') {
                         break;
                     }
-                    bracket += "'";
+                    bracket.append("'");
                 }
                 if (bracket.length() > 1) {
                     // 2個以上は強調表示
-                    int idx2 = WdicUtil.indexOf(str, bracket, idx1);
+                    int idx2 = WdicUtil.indexOf(str, bracket.toString(), idx1);
                     if (idx2 != -1) {
                         // 強調
                         _appendRawText(node, buf.toString());
@@ -2073,11 +2072,11 @@ public class Wdic2Xml {
                     idx += cnt;
                     continue;
                 }
+                int end = idx + cnt;
                 Character.UnicodeBlock unicodeBlock = Character.UnicodeBlock.of(codePoint);
                 if (Character.UnicodeBlock.HEBREW.equals(unicodeBlock)
-                           || Character.UnicodeBlock.ARABIC.equals(unicodeBlock)
-                           || Character.UnicodeBlock.DEVANAGARI.equals(unicodeBlock)) {
-                    int end = idx + cnt;
+                    || Character.UnicodeBlock.ARABIC.equals(unicodeBlock)
+                    || Character.UnicodeBlock.DEVANAGARI.equals(unicodeBlock)) {
                     while (end<len) {
                         int cp = str.codePointAt(end);
                         if (!unicodeBlock.equals(Character.UnicodeBlock.of(cp))) {
@@ -2092,7 +2091,15 @@ public class Wdic2Xml {
                         }
                         end += Character.charCount(cp);
                     }
+                }
+                if (end > idx+cnt) {
                     String s = str.substring(idx, end);
+                    Node parent = text.getParentNode();
+                    text = text.splitText(idx);
+                    text.deleteData(0, end-idx);
+                    Element nobr = text.getOwnerDocument().createElement("nobr");
+                    parent.insertBefore(nobr, text);
+
                     int n = s.length();
                     StringBuilder buf = new StringBuilder();
                     for (int i=0; i<n; i++) {
@@ -2118,7 +2125,7 @@ public class Wdic2Xml {
                                   + " " + unicodeBlock.toString());
                         BufferedImage img = WdicUtil.toImage(s);
                         int height = img.getHeight();
-                        int width = 16;
+                        int width = 8;
                         byte[][] b = FontUtil.split(img, width);
                         img.flush();
                         n = b.length;
@@ -2134,20 +2141,12 @@ public class Wdic2Xml {
                     } else {
                         n = files.length;
                     }
-                    Node parent = text.getParentNode();
-                    text = text.splitText(idx);
-                    text.deleteData(0, end-idx);
                     for (int i=0; i<n; i++) {
                         String name0 = name + i;
-                        String type = _gaijiMap.get(name0);
-                        if (type == null) {
-                            type = "wide";
-                            _gaijiMap.put(name0, type);
+                        if (!_gaijiMap.containsKey(name0)) {
+                            _gaijiMap.put(name0, "narrow");
                         }
-                        Element elem = text.getOwnerDocument().createElement("char");
-                        elem.setAttribute("name", name0);
-                        elem.setAttribute("type", type);
-                        parent.insertBefore(elem, text);
+                        _appendCharReference(nobr, name0, "narrow");
                     }
                 } else {
                     String hex = HexUtil.toHexString(codePoint, 6);
