@@ -30,7 +30,7 @@ public class WdicMan {
     private static final Pattern SEC_PATTERN = Pattern.compile("^-+\\s\\u25a0\\s(\\S*)\\s\\u25a0\\s-+$");
 
     /** ログ */
-    private transient Log _log = null;
+    private Log _log = null;
     /** マニュアルファイル */
     private File _file = null;
     /** 著作権情報 */
@@ -92,9 +92,6 @@ public class WdicMan {
      */
     private void _load() {
         _log.info("load file: " + _file.getPath());
-
-        Pattern itemPattern = Pattern.compile("^\\s+(\\S+)\\s+(\\S+)$");
-
         LineIterator it = null;
         try {
             it = FileUtils.lineIterator(_file, ENCODING);
@@ -573,10 +570,8 @@ public class WdicMan {
                 }
             } else {
                 String str = StringUtils.stripStart(line, " ");
-                if (buf.length() == 0) {
-                    if (!numlist.matcher(str).matches()) {
-                        buf.append("\t");
-                    }
+                if (buf.length() == 0 && !numlist.matcher(str).matches()) {
+                    buf.append("\t");
                 }
                 buf.append(str);
             }
@@ -611,7 +606,7 @@ public class WdicMan {
                 String val = m.group(2);
                 StringBuilder buf = new StringBuilder();
                 buf.append(name);
-                int len = 10 - _getLength(name);
+                int len = 14 - _getLength(name);
                 for (int i=0; i<len; i++) {
                     buf.append(" ");
                 }
