@@ -9,6 +9,7 @@ import java.awt.RenderingHints;
 import java.awt.image.BufferedImage;
 import java.util.ArrayList;
 
+import org.apache.commons.lang.ArrayUtils;
 import org.apache.commons.lang.CharUtils;
 import org.apache.commons.lang.StringUtils;
 import org.apache.commons.logging.LogFactory;
@@ -20,6 +21,7 @@ import fuku.xml2eb.util.WaitImageObserver;
 /**
  * テーブル要素クラス。
  *
+ * @author Hisaya FUKUMOTO
  */
 public class WdicTableItem {
 
@@ -34,7 +36,7 @@ public class WdicTableItem {
     public static final int RIGHT = 2;
 
     /** ログ */
-    private transient Log _log = null;
+    private Log _log = null;
     /** 辞書項目 */
     private WdicItem _item = null;
 
@@ -275,7 +277,10 @@ public class WdicTableItem {
         if (_imgs == null) {
             _makeImage();
         }
-        return _imgs;
+        int n = ArrayUtils.getLength(_imgs);
+        BufferedImage[] imgs = new BufferedImage[n];
+        System.arraycopy(_imgs, 0, imgs, 0, n);
+        return imgs;
     }
 
     /**
@@ -398,17 +403,17 @@ public class WdicTableItem {
             }
 
             if (ch == '\'') {
-                String bracket = "'";
+                StringBuilder bracket = new StringBuilder("'");
                 int idx1 = i + 1;
                 for (; idx1<len; idx1++) {
                     if (str.charAt(idx1) != '\'') {
                         break;
                     }
-                    bracket += "'";
+                    bracket.append("'");
                 }
                 if (bracket.length() > 1) {
                     // 2個以上は強調表示
-                    int idx2 = WdicUtil.indexOf(str, bracket, idx1);
+                    int idx2 = WdicUtil.indexOf(str, bracket.toString(), idx1);
                     if (idx2 != -1) {
                         // 強調
                         if (buf.length() > 0) {
@@ -732,10 +737,36 @@ public class WdicTableItem {
             String drawStr = str;
             int yy = y;
             int n = font.canDisplayUpTo(str);
+            if (n == 0 && font.getStyle() != Font.PLAIN) {
+                Font plainFont = font.deriveFont(Font.PLAIN, font.getSize2D());
+                n = plainFont.canDisplayUpTo(str);
+                if (n != 0) {
+                    Character.UnicodeBlock unicodeBlock = Character.UnicodeBlock.of(codePoint);
+                    String code = "U+" + HexUtil.toHexString(codePoint, 6);
+                    String style = "PLAIN";
+                    if (font.isBold()) {
+                        if (font.isItalic()) {
+                            style = "BOLD|ITALIC";
+                        } else {
+                            style = "BOLD";
+                        }
+                    } else if (font.isItalic()) {
+                        style = "ITALIC";
+                    }
+                    _log.warn("unavailable display font: [" + code + "]"
+                              + " block:" + unicodeBlock.toString()
+                              + " font:" + font.getName()
+                              + " style:" + style
+                              + " size:" + font.getSize()
+                              + " (using plain font)");
+                    font = plainFont;
+                }
+            }
             if (n == -1) {
                 // すべて表示可能
                 str = null;
             } else if (n == 0) {
+                str = str.substring(Character.charCount(codePoint));
                 Character.UnicodeBlock unicodeBlock = Character.UnicodeBlock.of(codePoint);
                 if (Character.UnicodeBlock.KATAKANA_PHONETIC_EXTENSIONS.equals(unicodeBlock)) {
                     // 通常のカタカナを小さくして描画
@@ -748,6 +779,8 @@ public class WdicTableItem {
                     int btm = y + fm1.getAscent() + fm1.getDescent();
                     yy = btm - fm2.getAscent() - fm2.getDescent();
                     drawStr = String.valueOf(Character.toChars(codePoint));
+                } else if (font.canDisplay(codePoint)) {
+                    drawStr = String.valueOf(Character.toChars(codePoint));
                 } else {
                     // 表示できない文字は'?'を描画
                     String code = "U+" + HexUtil.toHexString(codePoint, 6);
@@ -759,7 +792,6 @@ public class WdicTableItem {
                     font = font.deriveFont(origFont.getStyle(),
                                            origFont.getSize2D()-2.0f);
                 }
-                str = str.substring(1);
             } else {
                 // 表示可能な文字を描画
                 drawStr = str.substring(0, n);
