@@ -77,6 +77,7 @@ public class WdicUtil {
             } finally {
                 IOUtils.closeQuietly(fis);
             }
+            ArrayList<Font> fontList = new ArrayList<Font>();
             Iterator<?> it = prop.getKeys();
             while (it.hasNext()) {
                 String key = (String)it.next();
@@ -85,14 +86,22 @@ public class WdicUtil {
                 if (n == 0) {
                     continue;
                 }
-                Font[] fonts = new Font[n];
+                fontList.clear();
                 for (int i=0; i<n; i++) {
-                    fonts[i] = fontMap.get(family[i]);
-                    if (fonts[i] == null) {
-                        fonts[i] = new Font(family[i], Font.PLAIN, 1);
-                        fontMap.put(family[i], fonts[i]);
+                    Font font = fontMap.get(family[i]);
+                    if (font == null) {
+                        font = new Font(family[i], Font.PLAIN, 1);
+                        if (font.getName().equals(family[i])) {
+                            fontMap.put(family[i], font);
+                            fontList.add(font);
+                        } else {
+                            _log.error("unknown font name: " + family[i]);
+                        }
+                    } else {
+                        fontList.add(font);
                     }
                 }
+                Font[] fonts = fontList.toArray(new Font[fontList.size()]);
                 if ("default".equals(key)) {
                     DEFAULT_FONT = fonts;
                 } else {
@@ -335,7 +344,7 @@ public class WdicUtil {
                 try {
                     codePoint = Integer.parseInt(code, 16);
                     buf.appendCodePoint(codePoint);
-                } catch (Exception e) {
+                } catch (NumberFormatException e) {
                     _log.error("unknown character code: " + code);
                 }
             } else {
@@ -547,68 +556,28 @@ public class WdicUtil {
      * @return フォント
      */
     public static Font getFont(int codePoint) {
-        if (!Character.isSupplementaryCodePoint(codePoint)) {
-            // Unicode -> EUC-JP
-            String str = String.valueOf(Character.toChars(codePoint));
-            byte[] b = null;
-            try {
-                b = str.getBytes("EUC-JP");
-            } catch (Exception e) {
-            }
-            if (!ArrayUtils.isEmpty(b)) {
-                boolean unknown = true;
-                int c1 = b[0] & 0xff;
-                int c2;
-                if (c1 == 0x3f && codePoint != '?') {
-                    // EUC-JPでない不明な文字
-                } else if (c1 >= 0x20 && c1 <= 0x7e) {
-                    // G0(ASCII)
-                    unknown = false;
-                } else if (c1 >= 0xa1 && c1 <= 0xfe) {
-                    // G1 (JISX0208)
-                    c2 = b[1] & 0xff;
-                    if (c2 >= 0xa1 && c2 <= 0xfe) {
-                        // JISX0208の文字コード
-                        unknown = false;
-                    }
-                } else if (c1 == 0x8e) {
-                    // G2 (JISX0201)
-                    c2 = b[1] & 0xff;
-                    if (c2 >= 0xa1 && c2 <= 0xdf) {
-                        // 半角カナの文字コード
-                        unknown = false;
-                    }
-                }
-                if (!unknown) {
-                    int len = ArrayUtils.getLength(DEFAULT_FONT);
-                    for (int i=0; i<len; i++) {
-                        if (DEFAULT_FONT[i].canDisplay(codePoint)) {
-                            return DEFAULT_FONT[i];
-                        }
-                    }
-                }
-            }
-        }
-        Character.UnicodeBlock unicodeBlock = Character.UnicodeBlock.of(codePoint);
+        // コード指定フォント
         Font font = _fontCodeMap.get(codePoint);
-        if (font == null) {
-            Font[] fonts = _fontBlockMap.get(unicodeBlock);
-            int len = ArrayUtils.getLength(fonts);
-            for (int i=0; i<len; i++) {
-                if (fonts[i].canDisplay(codePoint)) {
-                    return fonts[i];
-                }
-            }
-        } else if (font.canDisplay(codePoint)) {
+        if (font != null && font.canDisplay(codePoint)) {
             return font;
         }
-        if (font == null) {
-            String code = "U+" + HexUtil.toHexString(codePoint, 6);
-            _log.info("undefined font: [" + code + "]"
-                      + " " + unicodeBlock.toString());
+
+        // ブロック指定フォント
+        Character.UnicodeBlock unicodeBlock = Character.UnicodeBlock.of(codePoint);
+        Font[] fonts = _fontBlockMap.get(unicodeBlock);
+        int len = ArrayUtils.getLength(fonts);
+        for (int i=0; i<len; i++) {
+            if (fonts[i].canDisplay(codePoint)) {
+                return fonts[i];
+            }
         }
+
+        String code = "U+" + HexUtil.toHexString(codePoint, 6);
+        _log.info("undefined font: [" + code + "]"
+                  + " " + unicodeBlock.toString());
+
         // デフォルトフォントから検索
-        int len = ArrayUtils.getLength(DEFAULT_FONT);
+        len = ArrayUtils.getLength(DEFAULT_FONT);
         for (int i=0; i<len; i++) {
             if (DEFAULT_FONT[i].canDisplay(codePoint)) {
                 return DEFAULT_FONT[i];
