@@ -3,10 +3,7 @@ package fuku.xml2eb;
 import java.io.File;
 import java.io.OutputStream;
 import java.io.IOException;
-import java.io.UnsupportedEncodingException;
 import java.util.Arrays;
-import java.util.Locale;
-import java.util.Map;
 import java.util.Stack;
 import javax.sound.sampled.AudioFormat;
 
@@ -43,7 +40,7 @@ public class TextOutputStream extends BlockOutputStream {
     private static final Integer SOUND = Integer.valueOf(9);
 
     /** ログ */
-    private transient Log _log = null;
+    private Log _log = null;
 
     /** 制御記述子スタック */
     private Stack<Integer> _stack = new Stack<Integer>();;
@@ -95,6 +92,7 @@ public class TextOutputStream extends BlockOutputStream {
      *
      * @exception IOException 入出力エラーが発生した場合
      */
+    @Override
     public void close() throws IOException {
         if (_indent > 0) {
             byte[] val = new byte[4];
@@ -116,6 +114,7 @@ public class TextOutputStream extends BlockOutputStream {
      * @param len 書き込むバイト数
      * @exception IOException 入出力エラーが発生した場合
      */
+    @Override
     public void write(byte[] b, int off, int len) throws IOException {
         if (_indent > 0) {
             byte[] val = new byte[4];
@@ -134,6 +133,7 @@ public class TextOutputStream extends BlockOutputStream {
      *
      * @return 書き込みバイト数
      */
+    @Override
     public long getSize() {
         long size = super.getSize();
         if (_indent > 0) {
