@@ -73,7 +73,7 @@ public class Xml2Eb {
     private static final int MAX_FONT = 94 * 94;
 
     /** ログ */
-    private transient Log _log = null;
+    private Log _log = null;
 
     /** ベースディレクトリ */
     private File _basedir = null;
